@@ -1,17 +1,20 @@
 package HTTP::Throwable::Role::JSONBody;
 # ABSTRACT - JSON Body
-$HTTP::Throwable::Role::JSONBody::VERSION = '0.001';
+$HTTP::Throwable::Role::JSONBody::VERSION = '0.002';
 use Moo::Role;
 use JSON::MaybeXS;
 
 has payload => (
   is => 'ro',
-  required => 1,
 );
 
 sub body {
   my $self = shift;
 
+  # Preempt bad clients that can't handle application/json with empty
+  # body
+  return "{}" unless $self->payload;
+
   return encode_json($self->payload);
 }
 
@@ -42,13 +45,14 @@ HTTP::Throwable::Role::JSONBody
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 OVERVIEW
 
-This role does two things - accepts a C<payload> argument that should be
-anything you can pass to L<JSON/"encode_json">, and then encodes it as the
-body, specifying a C<Content-Type> of C<application/json>.
+This role does two things - accepts an optional C<payload> argument that
+should be anything you can pass to L<JSON/"encode_json">, and then encodes
+it as the body, specifying a C<Content-Type> of C<application/json>. If no
+C<payload> is provided, the body will be C<{}>.
 
 =head1 AUTHOR
 
@@ -67,8 +71,9 @@ __END__
 
 #pod =head1 OVERVIEW
 #pod
-#pod This role does two things - accepts a C<payload> argument that should be
-#pod anything you can pass to L<JSON/"encode_json">, and then encodes it as the
-#pod body, specifying a C<Content-Type> of C<application/json>.
+#pod This role does two things - accepts an optional C<payload> argument that
+#pod should be anything you can pass to L<JSON/"encode_json">, and then encodes
+#pod it as the body, specifying a C<Content-Type> of C<application/json>. If no
+#pod C<payload> is provided, the body will be C<{}>.
 #pod
 #pod =cut
